#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_ANY_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_ANY_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/simd/any.hpp>

#endif
